@@ -15,14 +15,14 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 """
-:mod:`rapport` -- Work Report Generator
-=======================================
+:mod:`rapport` -- Work report generator for the lazy
+====================================================
 
 .. automodule:: rapport
-   :synopsis: Work Report Generator
+   :synopsis: Work report generator for the lazy
 .. moduleauthor:: Sascha Peilicke <saschpe@gmx.de>
 """
 
 __author__ = "Sascha Peilicke <saschpe@gmx.de>"
-__version_info__ = ("0", "0", "9")
+__version_info__ = ("0", "1", "0")
 __version__ = ".".join(__version_info__)
